@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.72';
+  $CPAN::Perl::Releases::VERSION = '0.74';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -216,6 +216,10 @@ our $data =
     "tar.bz2" => "D/DO/DOM/perl-5.14.3-RC1.tar.bz2",
     "tar.gz" => "D/DO/DOM/perl-5.14.3-RC1.tar.gz",
   },
+  "5.14.3-RC2" => {
+    "tar.bz2" => "D/DO/DOM/perl-5.14.3-RC2.tar.bz2",
+    "tar.gz" => "D/DO/DOM/perl-5.14.3-RC2.tar.gz",
+  },
   "5.15.0" => {
     "tar.bz2" => "D/DA/DAGOLDEN/perl-5.15.0.tar.bz2",
     "tar.gz" => "D/DA/DAGOLDEN/perl-5.15.0.tar.gz",
@@ -407,7 +411,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.72
+version 0.74
 
 =head1 SYNOPSIS
 
